@@ -3,7 +3,7 @@ use warnings;
 
 package Git::Repository::Plugin::GitHooks;
 # ABSTRACT: A Git::Repository plugin with some goodies for hook developers
-$Git::Repository::Plugin::GitHooks::VERSION = '2.10.1';
+$Git::Repository::Plugin::GitHooks::VERSION = '2.11.0';
 use parent qw/Git::Repository::Plugin/;
 
 use 5.010;
@@ -1457,7 +1457,7 @@ sub _grok_groups_spec {
     foreach (@$specs) {
         s/\#.*//;               # strip comments
         next unless /\S/;       # skip blank lines
-        /^\s*(\w+)\s*=\s*(.+?)\s*$/
+        /^\s*([\w-]+)\s*=\s*(.+?)\s*$/
             or croak __PACKAGE__, ": invalid line in '$source': $_\n";
         my ($groupname, $members) = ($1, $2);
         exists $groups->{"\@$groupname"}
@@ -1595,7 +1595,7 @@ Git::Repository::Plugin::GitHooks - A Git::Repository plugin with some goodies f
 
 =head1 VERSION
 
-version 2.10.1
+version 2.11.0
 
 =head1 SYNOPSIS
 
@@ -2353,7 +2353,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2020 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
